% ----------------------
% TE.m
% ----------------------
% computes the temporary equilibrium for the global time 't'
% in:   -
% out:  edy
% ----------------------

function edyresid = TE()

global t mpc
global Y Div w I V K H C edy  r
global A_0 alpha L0 delta

% PRODUCTION AND INVESTMENT
Y(t)    = A_0*K(t)^alpha*L0^(1-alpha);
r(t+1)  = (V(t+1)+mpc*H(t+1))/((1-mpc)*(Y(t)+(1-delta)*K(t)))-1;
w(t)    = (1-alpha)*Y(t)/L0;
r(t)    = alpha*Y(t)/K(t)-delta;
I(t)    = V(t+1)/(1+r(t+1))-(1-delta)*K(t);
K(t+1)  = I(t)+(1-delta)*K(t);
Div(t)  = Y(t)-w(t)*L0-I(t);
V(t)    = Div(t)+V(t+1)/(1+r(t+1));

% CONSUMPTION AND SAVINGS
H(t)    = w(t)*L0+H(t+1)/(1+r(t+1));
C(t)    = mpc*(H(t)+V(t));

% EQUILIBRIUM
edy(t)  = I(t)+C(t)-Y(t);
edyresid = edy(t);

end

